@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 
 #   Copyright (C) 2004 Midori (midori -- a-t -- paipai dot net)
+#   Copyright (C) 2018 Ludovic Rousseau (ludovic.rousseau@free.fr)
 #
 # This file is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by
@@ -19,6 +20,7 @@
 from __future__ import print_function
 
 import PyKCS11.LowLevel
+from PyKCS11 import ckbytelist
 import os
 
 a = PyKCS11.LowLevel.CPKCS11Lib()
@@ -31,8 +33,8 @@ session = PyKCS11.LowLevel.CK_SESSION_HANDLE()
 sessionInfo = PyKCS11.LowLevel.CK_SESSION_INFO()
 tokenInfo = PyKCS11.LowLevel.CK_TOKEN_INFO()
 slotList = PyKCS11.LowLevel.ckintlist()
-pin = "123456"
-puk = "12345678"
+pin = ckbytelist("123456")
+puk = ckbytelist("12345678")
 Label = "PyKCS#11 Initialized Token      "
 
 print("Load of " + lib + ": " + str(a.Load(lib)))
