@@ -70,21 +70,17 @@ public:
 
 #endif
 	CK_RV C_InitToken(unsigned long slotID,
-		char* pPin,
-		unsigned long ulPinLen,
+		vector<unsigned char> pin,
 		const char* pLabel);
 
 	CK_RV C_InitPIN(
 		CK_SESSION_HANDLE hSession,
-		char* pPin,
-		unsigned long ulPinLen);
+		vector<unsigned char> pin);
 
 	CK_RV C_SetPIN(
 		CK_SESSION_HANDLE hSession,
-		char* pOldPin,
-		unsigned long ulOldLen,
-		char* pNewPin,
-		unsigned long ulNewLen);
+		vector<unsigned char> OldPin,
+		vector<unsigned char> NewPin);
 
 	CK_RV C_OpenSession(
 		unsigned long slotID,
@@ -102,7 +98,7 @@ public:
 	CK_RV C_Login(
 		CK_SESSION_HANDLE hSession,
 		unsigned long userType,
-		char* pPin, unsigned long ulPinLen);
+		vector<unsigned char> pin);
 #ifdef SWIG
 %clear (char* pPin, unsigned long ulPinLen),
 	(char* pOldPin, unsigned long ulOldLen),
